@@ -32,6 +32,7 @@
 #include <stack>
 #include <unordered_set>
 
+class CanonicalForm;
 
 namespace GiNaC {
 #ifdef _MSC_VER
@@ -136,7 +137,6 @@ public:
 	ex evalf(int level = 0, PyObject* parent=nullptr) const 
 	{ return bp->evalf(level, parent); }
 	ex eval_ncmul(const exvector & v) const { return bp->eval_ncmul(v); }
-	ex eval_integ() const { return bp->eval_integ(); }
 
 	// printing
 	void print(const print_context & c, unsigned level = 0) const;
@@ -151,6 +151,7 @@ public:
 	size_t nsymbols() const;
         bool get_first_symbol(ex &x) const;
         symbolset symbols() const;
+        symbolset free_symbols() const;
 	const ex op(size_t i) const { return bp->op(i); }
 	ex sorted_op(size_t i) const;
 	ex operator[](const ex & index) const { return (*bp)[index]; }
@@ -232,6 +233,8 @@ public:
 	void unitcontprim(const ex &x, ex &u, ex &c, ex &p) const;
 	ex smod(const numeric &xi) const { return bp->smod(xi); }
 	numeric max_coefficient() const;
+        bool is_linear(const symbol& x, ex& a, ex& b) const;
+        bool is_quadratic(const symbol& x, ex& a, ex& b, ex& c) const;
 
 	// indexed objects
 	exvector get_free_indices() const { return bp->get_free_indices(); }
@@ -758,9 +761,6 @@ inline ex eval(const ex & thisex, int level = 0)
 inline ex evalf(const ex & thisex, int level = 0, PyObject* parent=nullptr)
 { return thisex.evalf(level, parent); }
 
-inline ex eval_integ(const ex & thisex)
-{ return thisex.eval_integ(); }
-
 inline ex diff(const ex & thisex, const symbol & s, unsigned nth = 1)
 { return thisex.diff(s, nth); }
 
