@@ -40,8 +40,8 @@ class power : public basic
 {
 	GINAC_DECLARE_REGISTERED_CLASS(power, basic)
 	
-	friend struct print_order;
-	friend struct print_order_mul;
+	friend class print_order;
+	friend class print_order_mul;
 	friend class ex;
 	friend class mul;
 	
@@ -67,6 +67,7 @@ public:
 	ex eval(int level=0) const override;
 	ex evalf(int level=0, PyObject* parent=nullptr) const override;
 	ex series(const relational & s, int order, unsigned options = 0) const override;
+        void useries(flint_series_t& fp, int order) const override;
 	ex subs(const exmap & m, unsigned options = 0) const override;
 	bool has(const ex & other, unsigned options = 0) const override;
 	ex normal(exmap & repl, exmap & rev_lookup, int level = 0, unsigned options = 0) const override;
